<h2>
  Stable Diffusion + ControlNet + Keras Diffusion WebUI
</h2>

<a href="https://huggingface.co/spaces/ArtGAN/Stable-Diffusion-ControlNet-WebUI"><img src="https://img.shields.io/badge/%20HuggingFace%20-Demo-blue.svg" alt="HuggingFace Spaces"></a>

This repo is a Stable Diffusion(v1.5, v2.0 and v2.1) + ControlNet + Keras Diffusion WebUI implementation.

### Installation
```bash
git clone https://github.com/kadirnar/Stable-Diffusion-ControlNet-WebUI
cd Stable-Diffusion-ControlNet-WebUI
pip install -r requirements.txt
```
### Usage
```python
python3 app.py
```
